==> zio-aws-dataexchange_2.13-5.17.102.9-sources.jar: zio/aws/dataexchange/model/RedshiftDataShareAsset.scala <==
package zio.aws.dataexchange.model
import zio.aws.dataexchange.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class RedshiftDataShareAsset(arn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dataexchange.model.RedshiftDataShareAsset = {
    import RedshiftDataShareAsset.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dataexchange.model.RedshiftDataShareAsset
      .builder()
      .arn(__string.unwrap(arn): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.dataexchange.model.RedshiftDataShareAsset.ReadOnly =
    zio.aws.dataexchange.model.RedshiftDataShareAsset.wrap(buildAwsValue())
}
object RedshiftDataShareAsset {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dataexchange.model.RedshiftDataShareAsset
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.dataexchange.model.RedshiftDataShareAsset =
      zio.aws.dataexchange.model.RedshiftDataShareAsset(arn)
    def arn: __string
    def getArn: ZIO[Any, Nothing, __string] = ZIO.succeed(arn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dataexchange.model.RedshiftDataShareAsset
  ) extends zio.aws.dataexchange.model.RedshiftDataShareAsset.ReadOnly {
    override val arn: __string =
      zio.aws.dataexchange.model.primitives.__string(impl.arn())
  }
  def wrap(
      impl: software.amazon.awssdk.services.dataexchange.model.RedshiftDataShareAsset
  ): zio.aws.dataexchange.model.RedshiftDataShareAsset.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-dataexchange_2.13-5.17.171.1-sources.jar: zio/aws/dataexchange/model/RedshiftDataShareAsset.scala <==
package zio.aws.dataexchange.model
import zio.aws.dataexchange.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class RedshiftDataShareAsset(arn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dataexchange.model.RedshiftDataShareAsset = {
    import RedshiftDataShareAsset.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dataexchange.model.RedshiftDataShareAsset
      .builder()
      .arn(arn: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.dataexchange.model.RedshiftDataShareAsset.ReadOnly =
    zio.aws.dataexchange.model.RedshiftDataShareAsset.wrap(buildAwsValue())
}
object RedshiftDataShareAsset {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dataexchange.model.RedshiftDataShareAsset
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.dataexchange.model.RedshiftDataShareAsset =
      zio.aws.dataexchange.model.RedshiftDataShareAsset(arn)
    def arn: __string
    def getArn: ZIO[Any, Nothing, __string] = ZIO.succeed(arn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dataexchange.model.RedshiftDataShareAsset
  ) extends zio.aws.dataexchange.model.RedshiftDataShareAsset.ReadOnly {
    override val arn: __string = impl.arn(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.dataexchange.model.RedshiftDataShareAsset
  ): zio.aws.dataexchange.model.RedshiftDataShareAsset.ReadOnly = new Wrapper(
    impl
  )
}
